summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pminsertrulesystem.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:56:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:56:05 -0600
commit74c05bbf9d92e43a6cf3799355b5f3598884409e (patch)
tree9371e52e1564e08fd280f28e49981ffeb881b9d2 /kpovmodeler/pminsertrulesystem.cpp
parent45f529de247fc4b3662f6b474abe03fe904306ec (diff)
downloadtdegraphics-74c05bbf9d92e43a6cf3799355b5f3598884409e.tar.gz
tdegraphics-74c05bbf9d92e43a6cf3799355b5f3598884409e.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kpovmodeler/pminsertrulesystem.cpp')
-rw-r--r--kpovmodeler/pminsertrulesystem.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kpovmodeler/pminsertrulesystem.cpp b/kpovmodeler/pminsertrulesystem.cpp
index af899947..3c601df7 100644
--- a/kpovmodeler/pminsertrulesystem.cpp
+++ b/kpovmodeler/pminsertrulesystem.cpp
@@ -181,15 +181,15 @@ PMRuleCondition* newCondition( TQDomElement& e,
PMRuleBase::~PMRuleBase( )
{
- m_tqchildren.setAutoDelete( true );
- m_tqchildren.clear( );
+ m_children.setAutoDelete( true );
+ m_children.clear( );
}
void PMRuleBase::countChild( const TQString& className, bool afterInsertPoint )
{
countChildProtected( className, afterInsertPoint );
- TQPtrListIterator<PMRuleBase> it( m_tqchildren );
+ TQPtrListIterator<PMRuleBase> it( m_children );
for( ; it.current( ); ++it )
it.current( )->countChild( className, afterInsertPoint );
}
@@ -198,7 +198,7 @@ void PMRuleBase::reset( )
{
resetProtected( );
- TQPtrListIterator<PMRuleBase> it( m_tqchildren );
+ TQPtrListIterator<PMRuleBase> it( m_children );
for( ; it.current( ); ++it )
it.current( )->reset( );
}
@@ -302,7 +302,7 @@ PMRuleNot::PMRuleNot( TQDomElement& e,
if( isCondition( me ) )
{
m_pChild = newCondition( me, globalGroups, localGroups );
- m_tqchildren.append( m_pChild );
+ m_children.append( m_pChild );
}
}
m = m.nextSibling( );
@@ -330,7 +330,7 @@ PMRuleAnd::PMRuleAnd( TQDomElement& e,
if( isCondition( me ) )
{
PMRuleCondition* c = newCondition( me, globalGroups, localGroups );
- m_tqchildren.append( c );
+ m_children.append( c );
m_conditions.append( c );
}
}
@@ -361,7 +361,7 @@ PMRuleOr::PMRuleOr( TQDomElement& e,
if( isCondition( me ) )
{
PMRuleCondition* c = newCondition( me, globalGroups, localGroups );
- m_tqchildren.append( c );
+ m_children.append( c );
m_conditions.append( c );
}
}
@@ -533,7 +533,7 @@ PMRuleCompare::PMRuleCompare( TQDomElement& e,
if( isValue( me ) )
{
m_pValue[i] = newValue( me, globalGroups, localGroups );
- m_tqchildren.append( m_pValue[i] );
+ m_children.append( m_pValue[i] );
i++;
}
}
@@ -745,7 +745,7 @@ PMRule::PMRule( TQDomElement& e,
else if( isCondition( me ) )
{
m_pCondition = newCondition( me, globalGroups, localGroups );
- m_tqchildren.append( m_pCondition );
+ m_children.append( m_pCondition );
}
}
m = m.nextSibling( );
@@ -1006,7 +1006,7 @@ int PMInsertRuleSystem::canInsert( const PMObject* parentObject,
if( targetClassList.isEmpty( ) )
return 0; // not rules found
// count already inserted tqchildren
TQPtrListIterator<PMRuleTargetClass> tit( targetClassList );
for( ; tit.current( ); ++tit ) // ... for all target classes
{
@@ -1006,7 +1006,7 @@ int PMInsertRuleSystem::canInsert( const PMObject* parentObject,
if( targetClassList.isEmpty( ) )
return 0; // not rules found
- // count already inserted tqchildren
+ // count already inserted children
TQPtrListIterator<PMRuleTargetClass> tit( targetClassList );
for( ; tit.current( ); ++tit ) // ... for all target classes